@@ -2,10 +2,17 @@
 API to METS
 """
 from datetime import datetime
-from re import fullmatch
+from re import fullmatch, search
 from lxml import etree as ET
 
-from ocrd_utils import is_local_filename, getLogger, VERSION, REGEX_PREFIX, REGEX_FILE_ID
+from ocrd_utils import (
+    is_local_filename,
+    getLogger,
+    generate_range,
+    VERSION,
+    REGEX_PREFIX,
+    REGEX_FILE_ID
+)
 
 from .constants import (
     NAMESPACES as NS,
@@ -134,6 +141,10 @@ class OcrdMets(OcrdXmlDocument):
         and candidates are matched against the regex with `re.fullmatch`. If it is
         a literal string, comparison is done with string equality.
 
+        The ``pageId`` parameter supports the numeric range operator ``..``. For
+        example, to find all files in pages ``PHYS_0001`` to ``PHYS_0003``, 
+        ``PHYS_0001..PHYS_0003`` will be expanded to ``PHYS_0001,PHYS_0002,PHYS_0003``.
+
         Keyword Args:
             ID (string) : `@ID` of the `mets:file`
             fileGrp (string) : `@USE` of the `mets:fileGrp` to list files of
@@ -150,6 +161,11 @@ class OcrdMets(OcrdXmlDocument):
             if pageId.startswith(REGEX_PREFIX):
                 raise Exception("find_files does not support regex search for pageId")
             pageIds, pageId = pageId.split(','), list()
+            pageIds_expanded = []
+            for pageId_ in pageIds:
+                if '..' in pageId_:
+                    pageIds_expanded += generate_range(*pageId_.split('..', 2))
+            pageIds += pageIds_expanded
             for page in self._tree.getroot().xpath(
                 '//mets:div[@TYPE="page"]', namespaces=NS):
                 if page.get('ID') in pageIds:
@@ -430,3 +446,26 @@ class OcrdMets(OcrdXmlDocument):
             namespaces=NS)
         if mets_div:
             mets_div[0].getparent().remove(mets_div[0])
+
+    def merge(self, other_mets, fileGrp_mapping=None, after_add_cb=None, **kwargs):
+        """
+        Add all files from other_mets.
+
+        Accepts the same kwargs as :py:func:find_files
+
+        Keyword Args:
+            fileGrp_mapping (dict): Map ``other_mets`` fileGrp to fileGrp in this METS
+            after_add_cb (function): Callback received after file is added to the METS
+        """
+        if not fileGrp_mapping:
+            fileGrp_mapping = {}
+        for f_src in other_mets.find_files(**kwargs):
+            f_dest = self.add_file(
+                    fileGrp_mapping.get(f_src.fileGrp, f_src.fileGrp),
+                    mimetype=f_src.mimetype,
+                    url=f_src.url,
+                    ID=f_src.ID,
+                    pageId=f_src.pageId)
+            if after_add_cb:
+                after_add_cb(f_dest)
+
